@@ -1167,5 +1167,42 @@ class TestConservativeFuturize(CodeHandler):
         self.convert_check(before, after)
 
 
+class TestFuturizeAllImports(CodeHandler):
+    """
+    Tests "futurize --all-imports".
+    """
+    @expectedFailurePY26
+    def test_all_imports(self):
+        before = """
+        import math
+        import os
+        l = range(10)
+        assert isinstance(l, list)
+        print 'Hello'
+        for i in xrange(100):
+            pass
+        print('Hello')
+        """
+        after = """
+        from __future__ import unicode_literals
+        from __future__ import print_function
+        from __future__ import division
+        from __future__ import absolute_import
+        from future import standard_library
+        standard_library.install_hooks()
+        from future.builtins import range
+        from future.builtins import *
+        import math
+        import os
+        l = list(range(10))
+        assert isinstance(l, list)
+        print('Hello')
+        for i in range(100):
+            pass
+        print('Hello')
+        """
+        self.convert_check(before, after, all_imports=True)
+
+
 if __name__ == '__main__':
     unittest.main()
